@@ -81,7 +81,6 @@ class AFM(Model):
         return outputs
 
 
-
 class NFM(Model):
     def __init__(self, feature_columns, hidden_units, dnn_dropout=0., activation='relu', bn_use=True, embed_reg=1e-4):
         """
@@ -247,6 +246,9 @@ class xDeepFM(Model):
         output = tf.nn.sigmoid(cin_out + dnn_out + self.bias)
         return output
 
+    def get_config(self):
+        pass
+
 
 class MF_layer(Layer):
     def __init__(self, user_num, item_num, latent_dim, implicit=False, use_bias=False, user_reg=1e-4, item_reg=1e-4,
@@ -386,7 +388,6 @@ class WideDeep(Model):
         return outputs
 
 
-
 class DCN(Model):
     def __init__(self, feature_columns, hidden_units, activation='relu',
                  dnn_dropout=0., embed_reg=1e-4, cross_w_reg=1e-4, cross_b_reg=1e-4):
